@@ -117,9 +117,6 @@ class HandleRisk:
             print(
                 f"Services to exclude: {[engagement.name for engagement in excluded_engagements]}"
             )
-            logger.info(
-                f"Services to exclude: {[engagement.name for engagement in excluded_engagements]}"
-            )
 
             return remaining_engagements
         return service_list
@@ -226,8 +223,7 @@ class HandleRisk:
         )
 
         for engagement in new_service_list:
-            print(f"Service to analyze: {engagement.name}, URL: {engagement.vm_url}")
-            logger.info(
+            print(
                 f"Service to analyze: {engagement.name}, URL: {engagement.vm_url}"
             )
 
