@@ -404,7 +404,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
 
             if print_domain:
                 host_dd = print_domain
-                
+
             for engagement in engagements:
                 engagement.vm_url = f"{host_dd}/engagement/{engagement.id}/finding/open"
 
@@ -563,11 +563,16 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                     "product_type_name": vulnerability_management.vm_product_type_name,
                     "product_name": vulnerability_management.vm_product_name,
                     "product_description": vulnerability_management.vm_product_description,
-                    "code_app": vulnerability_management.vm_product_name,
+                    "code_app": Connect.get_code_app(
+                        vulnerability_management.vm_product_name,
+                        vulnerability_management.config_tool["VULNERABILITY_MANAGER"][
+                            "DEFECT_DOJO"
+                        ]["CMDB"]["REGEX_EXPRESSION_CMDB"],
+                    ),
                     **common_fields,
                 }
             )
-        
+
         return request
 
     def _process_component(self, component_sbom, session_manager, engagement):
@@ -669,7 +674,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
         findings = self._get_findings(
             session_manager, service, max_retries, query_params
         )
-        
+
         return map(
             partial(
                 self._create_exclusion,
@@ -849,4 +854,3 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
             return finding.file_path
         else:
             return finding.file_path
-        
\ No newline at end of file
